pub struct PolicyConfig {
pub allowlist: Vec<AllowlistRule>,
pub mcp_overrides: HashMap<String, McpToolOverride>,
}Expand description
Complete policy configuration loaded from policy.toml.
Fields
allowlist: Vec<AllowlistRule>Static allowlist rules.
mcp_overrides: HashMap<String, McpToolOverride>MCP tool overrides keyed by “server_name.tool_name”.
Implementations
Sourceimpl PolicyConfig
impl PolicyConfig
Sourcepub fn from_toml(content: &str) -> Result<Self, String>
pub fn from_toml(content: &str) -> Result<Self, String>
Parse a policy config from TOML string.
Sourcepub fn check_allowlist(
&self,
tool_name: &str,
target: Option<&str>,
taint: TaintLevel,
) -> Option<usize>
pub fn check_allowlist( &self, tool_name: &str, target: Option<&str>, taint: TaintLevel, ) -> Option<usize>
Check whether any allowlist rule matches the given invocation. Returns the index of the matching rule, if any.